[前][次][番号順一覧][スレッド一覧]

ruby-changes:51854

From: k0kubun <ko1@a...>
Date: Thu, 26 Jul 2018 22:05:53 +0900 (JST)
Subject: [ruby-changes:51854] k0kubun:r64068 (trunk): mjit.c: o -> so is not compilation

k0kubun	2018-07-26 22:05:47 +0900 (Thu, 26 Jul 2018)

  New Revision: 64068

  https://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=64068

  Log:
    mjit.c: o -> so is not compilation

  Modified files:
    trunk/mjit.c
Index: mjit.c
===================================================================
--- mjit.c	(revision 64067)
+++ mjit.c	(revision 64068)
@@ -815,9 +815,9 @@ compile_c_to_o(const char *c_file, const https://github.com/ruby/ruby/blob/trunk/mjit.c#L815
     return exit_code == 0;
 }
 
 /* Compile .o file to .so file. It returns 1 if it succeeds. (non-mswin) */
 static int
-compile_o_to_so(const char *o_file, const char *so_file)
+link_o_to_so(const char *o_file, const char *so_file)
 {
     int exit_code;
     const char *files[] = {
@@ -840,7 +840,7 @@ compile_o_to_so(const char *o_file, cons https://github.com/ruby/ruby/blob/trunk/mjit.c#L840
     free(args);
 
     if (exit_code != 0)
-        verbose(2, "compile_o_to_so: compile error: %d", exit_code);
+        verbose(2, "link_o_to_so: link error: %d", exit_code);
     return exit_code == 0;
 }
 
@@ -1018,8 +1018,7 @@ convert_unit_to_func(struct rb_mjit_unit https://github.com/ruby/ruby/blob/trunk/mjit.c#L1018
     success = compile_c_to_so(c_file, so_file);
 #else
     /* splitting .c -> .o and .o -> .so to cache .o files in the future */
-    success = compile_c_to_o(c_file, o_file)
-        && compile_o_to_so(o_file, so_file);
+    success = compile_c_to_o(c_file, o_file) && link_o_to_so(o_file, so_file);
 
     if (!mjit_opts.save_temps)
         remove_file(o_file);
@@ -815,9 +815,9 @@ compile_c_to_o(const char *c_file, const https://github.com/ruby/ruby/blob/trunk/mjit.c#L815
 }
 
-/* Compile .o file to .so file. It returns 1 if it succeeds. (non-mswin) */
+/* Link .o file to .so file. It returns 1 if it succeeds. (non-mswin) */
 static int

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]